/****************************************************************************
** Meta object code from reading C++ file 'intervalmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kopeninghours-26.04.1/src/lib/intervalmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'intervalmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KOpeningHours13IntervalModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KOpeningHours::IntervalModel::qt_create_metaobjectdata<qt_meta_tag_ZN13KOpeningHours13IntervalModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KOpeningHours::IntervalModel",
        "openingHoursChanged",
        "",
        "beginDateChanged",
        "endDateChanged",
        "beginOfWeek",
        "dt",
        "formatTimeColumnHeader",
        "hour",
        "minute",
        "openingHours",
        "KOpeningHours::OpeningHours",
        "beginDate",
        "endDate",
        "currentState"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openingHoursChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'beginDateChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'endDateChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'beginOfWeek'
        QtMocHelpers::MethodData<QDate(const QDateTime &) const>(5, 2, QMC::AccessPublic, QMetaType::QDate, {{
            { QMetaType::QDateTime, 6 },
        }}),
        // Method 'formatTimeColumnHeader'
        QtMocHelpers::MethodData<QString(int, int) const>(7, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 8 }, { QMetaType::Int, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'openingHours'
        QtMocHelpers::PropertyData<KOpeningHours::OpeningHours>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'beginDate'
        QtMocHelpers::PropertyData<QDate>(12, QMetaType::QDate, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'endDate'
        QtMocHelpers::PropertyData<QDate>(13, QMetaType::QDate, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'currentState'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IntervalModel, qt_meta_tag_ZN13KOpeningHours13IntervalModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KOpeningHours::IntervalModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KOpeningHours13IntervalModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KOpeningHours13IntervalModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KOpeningHours13IntervalModelE_t>.metaTypes,
    nullptr
} };

void KOpeningHours::IntervalModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IntervalModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openingHoursChanged(); break;
        case 1: _t->beginDateChanged(); break;
        case 2: _t->endDateChanged(); break;
        case 3: { QDate _r = _t->beginOfWeek((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDate*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->formatTimeColumnHeader((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IntervalModel::*)()>(_a, &IntervalModel::openingHoursChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IntervalModel::*)()>(_a, &IntervalModel::beginDateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IntervalModel::*)()>(_a, &IntervalModel::endDateChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KOpeningHours::OpeningHours >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KOpeningHours::OpeningHours*>(_v) = _t->openingHours(); break;
        case 1: *reinterpret_cast<QDate*>(_v) = _t->beginDate(); break;
        case 2: *reinterpret_cast<QDate*>(_v) = _t->endDate(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->currentState(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setOpeningHours(*reinterpret_cast<KOpeningHours::OpeningHours*>(_v)); break;
        case 1: _t->setBeginDate(*reinterpret_cast<QDate*>(_v)); break;
        case 2: _t->setEndDate(*reinterpret_cast<QDate*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KOpeningHours::IntervalModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KOpeningHours::IntervalModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KOpeningHours13IntervalModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int KOpeningHours::IntervalModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KOpeningHours::IntervalModel::openingHoursChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KOpeningHours::IntervalModel::beginDateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KOpeningHours::IntervalModel::endDateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
